Skip to contents

A sample of addresses in Groningen with point coordinates in EPSG:4326 and an example numeric amount column.

Usage

Groningen

Format

A data frame with 25,000 rows and 9 variables:

street

Street name.

number

House number.

letter

House letter.

suffix

House number suffix.

postal_code

Postal code.

city

City name.

lon

Longitude.

lat

Latitude.

amount

Example numeric amount.

BAG, the Dutch registry for addresses and buildings (Basisregistratie Adressen en Gebouwen), adapted for package examples.

Details

The amount column is an example value used in package examples and tests.