powered by
find_highest_concentration()
Automatically create a plot for objects obtained from find_highest_concentration().
# S3 method for concentration plot( x, type = c("concentration", "focal", "rasterized", "updated_focal"), color1 = NULL, max.rad = 20, ... )
x object of class concentration obtained from highest_concentration()
concentration
highest_concentration()
is one of "concentration" (default), "rasterized", "focal", "updated_focal". See details for more information.
color when one concentration is plotted (default is "#4B0055").
maximal radius for size of circles in plot (default is 20).
additional arguments.
Martin Haringa
More info for type:
"concentration": this is..
"focal": this is..
"rasterized": this is..
"updated_focal": this is..
x <- find_highest_concentration(Groningen, "amount") plot(x, "concentration") plot(x, "rasterized") plot(x, "focal") plot(x, "updated_focal")
Run the code above in your browser using DataLab