Learn R Programming

spatialrisk (version 0.7.3)

update_db: Save highest concentrations per cell for subsequent iterations

Description

Save highest concentrations per cell for subsequent iterations.

Usage

update_db(hf_conc_new, db, cells)

Arguments

hf_conc_new

highest concentrations from the current iteration, obtained from conc_per_cell_new().

db

data.frame containing previously saved highest concentrations.

cells

cells containing points associated with the current highest concentration to be removed from db.

Author

Martin Haringa