Update current rasterize for the next iteration.
update_rasterize(old_rasterized, extent, new_spatvector, col)SpatRaster used in the current iteration.
Extent of the cells corresponding to the coordinates with the highest concentration for the current iteration.Extent is output from terra::ext().
Updated SpatVector for next iteration.
Character. Variable name in new_spatvector.
Martin Haringa
Spatial extent refers to the geographic area covered by a spatial dataset. It defines the boundaries in terms of its geographic coordinates (north, east, south, west).