powered by
A sample of addresses in Groningen with point coordinates in EPSG:4326 and an example numeric amount column.
Groningen
A data frame with 25,000 rows and 9 variables:
Street name.
House number.
House letter.
House number suffix.
Postal code.
City name.
Longitude.
Latitude.
Example numeric amount.
The amount column is an example value used in package examples and tests.
amount