Determine the concentrations within the highest focal cells for the current iteration.
conc_per_cell_new(
high_foc,
dff,
value,
size,
points,
db,
radius,
crs_from,
crs_to,
lon,
lat
)data.frame containing cell ids with the top n focal values from the current iteration.
data.frame with all observations
column name in `dff` to find concentrations for.
size of cell in meters.
number of points per `size`.
data.frame containing previously saved highest concentrations.
radius of circle in meters.
crs from
crs to
Martin Haringa