Determine the concentrations within the highest focal cells for the current iteration.
concentration_per_candidate_cell(
candidate_cells,
dff,
value,
size,
points,
cache,
radius,
crs_metric,
lon,
lat
)data.frame containing cell ids with focal values selected for refinement in the current iteration.
data.frame with all observations
column name in `dff` to find concentrations for.
size of cell in meters.
number of points per `size`.
data.frame containing previously saved highest concentrations.
radius of circle in meters.
metric CRS used for candidate cell coordinates.
longitude column name.
latitude column name.
Martin Haringa