if (FALSE) {
# Find highest concentration with a precision of a grid of 25 meters
hc1 <- highest_concentration(Groningen, amount, radius = 200,
grid_distance = 25)
# Look for coordinates with even higher concentrations in the
# neighborhood of the coordinates with the highest concentration
hc1_nghb <- neighborhood_gh_search(hc1, max.call = 7000)
print(hc1_nghb)
# Create map with geohashes above the lowerbound
# The highest concentration lies in one of the geohashes
plot(hc1)
# Create map with highest concentration
plot(hc1_nghb)
}
Run the code above in your browser using DataLab