Skip to contents

A sample insurance portfolio with postal codes, insured amounts, population at 4-digit postcode level, and point coordinates in EPSG:4326.

Usage

insurance

Format

A data frame with 29,990 rows and 5 variables:

postcode

6-digit postal code.

population_pc4

Population for the corresponding 4-digit postcode area.

amount

Insured amount.

lon

Longitude of the corresponding 6-digit postal code.

lat

Latitude of the corresponding 6-digit postal code.

Details

This dataset is intended for examples and tests of spatial concentration workflows.

Author

Martin Haringa