A sample insurance portfolio with postal codes, insured amounts, population at 4-digit postcode level, and point coordinates in EPSG:4326.
insuranceA data frame with 29,990 rows and 5 variables:
6-digit postal code.
Population for the corresponding 4-digit postcode area.
Insured amount.
Longitude of the corresponding 6-digit postal code.
Latitude of the corresponding 6-digit postal code.
Martin Haringa
This dataset is intended for examples and tests of spatial concentration workflows.