Deprecated. Spline interpolation and smoothing on the sphere. This function is outside the main scope of spatialrisk and will be removed in a future release.
Usage
interpolate_spline(
observations,
targets,
value,
lon_obs = lon,
lat_obs = lat,
lon_targets = lon,
lat_targets = lat,
k = 50
)Arguments
- observations
data.frame of observations.
- targets
data.frame of locations to calculate the interpolated and smoothed values for.
- value
Column with values in
observations.- lon_obs
Column in
observationswith longitude.- lat_obs
Column in
observationswith latitude.- lon_targets
Column in
targetswith longitude.- lat_targets
Column in
targetswith latitude.- k
Basis dimension. For small data sets reduce
kmanually.