Deprecated. Spline interpolation and smoothing on the sphere. This function is outside the main scope of spatialrisk and will be removed in a future release.
interpolate_spline(
observations,
targets,
value,
lon_obs = lon,
lat_obs = lat,
lon_targets = lon,
lat_targets = lat,
k = 50
)Object equal to targets with an extra prediction column.
data.frame of observations.
data.frame of locations to calculate the interpolated and smoothed values for.
Column with values in observations.
Column in observations with longitude.
Column in observations with latitude.
Column in targets with longitude.
Column in targets with latitude.
Basis dimension. For small data sets reduce k manually.