powered by
Creates an interactive map for a data.frame containing point coordinates, optionally colored by a selected variable.
map_points( data, value = NULL, lon = "lon", lat = "lat", crs = 4326, at = NULL, layer_name = NULL, ... )
An interactive mapview object.
mapview
A data.frame containing columns for longitude and latitude.
A string giving the name of the column in data to be visualized. If NULL, points are mapped without a color variable.
data
NULL
A string with the name of the column containing longitude values. Default is "lon".
"lon"
A string with the name of the column containing latitude values. Default is "lat".
"lat"
Integer; EPSG code for the coordinate reference system. Default is 4326.
4326
Optional numeric vector; breakpoints used for visualization.
Optional layer name passed to mapview.
Additional arguments passed to mapview::mapview().
mapview::mapview()
if (FALSE) { map_points(Groningen, value = "amount") }
Run the code above in your browser using DataLab