Visualise objects returned by concentration_hotspot().
The default plot shows hotspot
centres, fixed-radius buffers, and the contributing points. For terra-based
results, diagnostic raster layers can also be plotted.
Arguments
- x
An object of class
hotspot.- type
Plot type.
"concentration"shows hotspot buffers and contributing points and works for all hotspot search methods."focal","rasterized", and"updated_focal"are diagnostic terra layers and are only available for terra-based results.- color1
Optional colour or colours for hotspot buffers and points. If
NULL, colours are chosen withgrDevices::hcl.colors().- max.rad
Maximum point radius passed to
mapview::mapview(). Default is20.- ...
Additional arguments passed to
mapview::mapview()for the contributing point layer whentype = "concentration", or to the raster mapview call for diagnostic raster layers.