powered by
Deprecated.
Creates an interactive map for a data.frame containing point coordinates, optionally colored by a selected variable.
plot_points( df, value = NULL, lon = "lon", lat = "lat", crs = 4326, at = NULL, layer_name = NULL, ... )map_points( data, value = NULL, lon = "lon", lat = "lat", crs = 4326, at = NULL, layer_name = NULL, ... )
map_points( data, value = NULL, lon = "lon", lat = "lat", crs = 4326, at = NULL, layer_name = NULL, ... )
An interactive mapview object.
mapview
Deprecated. Use data instead.
data
`plot_points()` was renamed to [map_points()].
A string giving the name of the column in data to be visualized. If NULL, points are mapped without a color variable.
NULL
A string with the name of the column containing longitude values. Default is "lon".
"lon"
A string with the name of the column containing latitude values. Default is "lat".
"lat"
Integer; EPSG code for the coordinate reference system. Default is 4326.
4326
Optional numeric vector; breakpoints used for visualization.
Optional layer name passed to mapview.
Additional arguments passed to mapview::mapview().
mapview::mapview()
A data.frame containing columns for longitude and latitude.
if (FALSE) { map_points(Groningen, value = "amount") }
Run the code above in your browser using DataLab