powered by
Join a data.frame containing coordinates (longitude and latitude) to polygon geometries. Arithmetic operations are then applied to the attributes of the joined coordinates to obtain aggregated values for each polygon.
points_to_polygon(sf_map, df, oper, crs = 4326, outside_print = FALSE)
An object of class sf
sf
object of class sf representing the polygon geometries.
data.frame containing coordinates (column names should be 'lon' and 'lat')
arithmetic operation to be applied on the polygon level.
coordinate reference system (default is 4326).
logical indicating whether to print points that are not within a polygon (default is FALSE).
Martin Haringa
points_to_polygon(nl_postcode2, insurance, sum(amount, na.rm = TRUE)) if (FALSE) { shp_read <- sf::st_read("~/path/to/file.shp") points_to_polygon(shp_read, insurance, sum(amount, na.rm = TRUE)) }
Run the code above in your browser using DataLab